@@ -4,7 +4,7 @@ Name: "anderson"
 
 Import:
 
-    >>> from evidently.calculations.stattests import anderson_darling_test
+    >>> from mlopsdna.evidently.calculations.stattests import anderson_darling_test
 
 Properties:
 - only for numerical features
@@ -13,13 +13,13 @@ Properties:
 Example:
     Using by object:
 
-    >>> from evidently.options import DataDriftOptions
-    >>> from evidently.calculations.stattests import anderson_darling_test
+    >>> from mlopsdna.evidently.options import DataDriftOptions
+    >>> from mlopsdna.evidently.calculations.stattests import anderson_darling_test
     >>> options = DataDriftOptions(all_features_stattest=anderson_darling_test)
 
     Using by name:
 
-    >>> from evidently.options import DataDriftOptions
+    >>> from mlopsdna.evidently.options import DataDriftOptions
     >>> options = DataDriftOptions(all_features_stattest="anderson")
 """
 from typing import Tuple
@@ -28,8 +28,8 @@ import numpy as np
 import pandas as pd
 from scipy.stats import anderson_ksamp
 
-from evidently.calculations.stattests.registry import StatTest
-from evidently.calculations.stattests.registry import register_stattest
+from mlopsdna.evidently.calculations.stattests.registry import StatTest
+from mlopsdna.evidently.calculations.stattests.registry import register_stattest
 
 
 def _anderson_darling(
