@@ -1,6 +1,6 @@
-from evidently.features import trigger_words_presence_feature
-from evidently.features.generated_features import FeatureDescriptor
-from evidently.features.generated_features import GeneratedFeature
+from mlopsdna.evidently.features import trigger_words_presence_feature
+from mlopsdna.evidently.features.generated_features import FeatureDescriptor
+from mlopsdna.evidently.features.generated_features import GeneratedFeature
 
 
 class TriggerWordsPresence(FeatureDescriptor):
