@@ -1,9 +1,9 @@
 import pandas as pd
 
-from evidently.base_metric import ColumnName
-from evidently.base_metric import additional_feature
-from evidently.features.generated_features import GeneratedFeature
-from evidently.utils.data_preprocessing import DataDefinition
+from mlopsdna.evidently.base_metric import ColumnName
+from mlopsdna.evidently.base_metric import additional_feature
+from mlopsdna.evidently.features.generated_features import GeneratedFeature
+from mlopsdna.evidently.utils.data_preprocessing import DataDefinition
 
 
 class TextLength(GeneratedFeature):
