@@ -1,6 +1,6 @@
 from typing import Generator
 
-import evidently.utils.data_operations
+import mlopsdna.evidently.utils.data_operations
 from mlopsdna.evidently.analyzers.classification_performance_analyzer import ClassificationPerformanceAnalyzer
 from mlopsdna.evidently.analyzers.classification_performance_analyzer import ClassificationPerformanceMetrics
 from mlopsdna.evidently.model_monitoring.monitoring import MetricsType
