@@ -7,9 +7,9 @@ from typing import Type
 
 import pandas
 
-from evidently import ColumnMapping
-from evidently.analyzers.base_analyzer import Analyzer
-from evidently.options import OptionsProvider
+from mlopsdna.evidently import ColumnMapping
+from mlopsdna.evidently.analyzers.base_analyzer import Analyzer
+from mlopsdna.evidently.options import OptionsProvider
 
 
 class PipelineStage:
