@@ -6,8 +6,8 @@ import click
 from pyfiglet import Figlet
 from rich.console import Console
 
-#from bmomd.nannyml import __version__
-from bmomd.nannyml.config import Config, get_config_path
+#from mlopsdna.nannyml import __version__
+from mlopsdna.nannyml.config import Config, get_config_path
 
 
 @click.group()
