@@ -8,19 +8,19 @@
 
 """Module containing plotting implementations."""
 
-from bmomd.nannyml.plots.colors import Colors
-from bmomd.nannyml.plots.components.figure import Figure  # noqa: E402
-from bmomd.nannyml.plots.components.hover import (
+from mlopsdna.nannyml.plots.colors import Colors
+from mlopsdna.nannyml.plots.components.figure import Figure  # noqa: E402
+from mlopsdna.nannyml.plots.components.hover import (
     Hover,
     render_alert_string,
     render_partial_target_string,
     render_period_string,
     render_x_coordinate,
 )
-from bmomd.nannyml.plots.components.joy_plot import calculate_chunk_distributions, joy
-from bmomd.nannyml.plots.components.stacked_bar_plot import calculate_value_counts, stacked_bar
-from bmomd.nannyml.plots.components.step_plot import alert, metric
-from bmomd.nannyml.plots.util import (
+from mlopsdna.nannyml.plots.components.joy_plot import calculate_chunk_distributions, joy
+from mlopsdna.nannyml.plots.components.stacked_bar_plot import calculate_value_counts, stacked_bar
+from mlopsdna.nannyml.plots.components.step_plot import alert, metric
+from mlopsdna.nannyml.plots.util import (
     add_artificial_endpoint,
     check_and_convert,
     ensure_numpy,
