@@ -8,10 +8,10 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 import numpy as np
 import pandas as pd
 
-from bmomd.nannyml._typing import Result
-from bmomd.nannyml.plots import Colors
-from bmomd.nannyml.plots.components import Figure, Hover, render_alert_string, render_period_string, render_x_coordinate
-from bmomd.nannyml.plots.util import ensure_numpy, is_time_based_x_axis
+from mlopsdna.nannyml._typing import Result
+from mlopsdna.nannyml.plots import Colors
+from mlopsdna.nannyml.plots.components import Figure, Hover, render_alert_string, render_period_string, render_x_coordinate
+from mlopsdna.nannyml.plots.util import ensure_numpy, is_time_based_x_axis
 
 
 def plot_2d_compare_step_to_step(
@@ -554,11 +554,11 @@ class ResultCompareMixin:
         return ResultComparison(self, other, title=self._get_title(other))  # type: ignore
 
     def _get_title(self, other: Result):
-        from bmomd.nannyml.drift.multivariate.data_reconstruction import Result as DataReconstructionDriftResult
-        from bmomd.nannyml.drift.univariate import Result as UnivariateDriftResult
-        from bmomd.nannyml.performance_calculation import Result as RealizedPerformanceResult
-        from bmomd.nannyml.performance_estimation.confidence_based import Result as CBPEResult
-        from bmomd.nannyml.performance_estimation.direct_loss_estimation import Result as DLEResult
+        from mlopsdna.nannyml.drift.multivariate.data_reconstruction import Result as DataReconstructionDriftResult
+        from mlopsdna.nannyml.drift.univariate import Result as UnivariateDriftResult
+        from mlopsdna.nannyml.performance_calculation import Result as RealizedPerformanceResult
+        from mlopsdna.nannyml.performance_estimation.confidence_based import Result as CBPEResult
+        from mlopsdna.nannyml.performance_estimation.direct_loss_estimation import Result as DLEResult
 
         _result_title_names: Dict[type, Any] = {
             UnivariateDriftResult: "Univariate drift",
