@@ -20,7 +20,7 @@ from typing import Tuple, Union
 import numpy as np
 import pandas as pd
 
-from bmomd.nannyml.exceptions import InvalidArgumentsException
+from mlopsdna.nannyml.exceptions import InvalidArgumentsException
 
 
 def _universal_sampling_error(reference_std, reference_fraction, data):
